# Home
## 🏡 About This Documentation

This documentation hub details the design, setup, and day-to-day management of my personal homelab environment. The content is shared to benefit others exploring similar projects, from newcomers to advanced users. Topics range from initial hardware choices to complex network and automation workflows.

!!! info "General Purpose"
    - Provide a transparent look into my homelab architecture.
    - Share practical guides, workflows, and lessons learned.
    - Help others adapt and improve their own setups.

---

## 📂 What You’ll Find Here
This site is organized into several main areas:

**Hardware**

- Rack and device inventory
- Storage solutions (disk arrays, NAS, SSD/HDD, etc.)
- UPS and power management

**Networking**

- Physical and virtual network topology
- VLAN, subnets, and IP management
- Firewall and security rules
- Docker and container network configurations

**Servers & Virtualization**

- Host OS installation and hardening
- Proxmox, Docker, Kubernetes deployment notes
- VM/container orchestration
- Infrastructure-as-Code

**Automation & Monitoring**

- Ansible playbooks and workflows
- Monitoring stacks (Prometheus, Grafana, etc.)
- Alerting and log management

**Application Services**

- Self-hosted applications and deployment strategies
- Reverse proxies, SSL, and SSO integration
- Routine maintenance and update automation

**General Tips & Reference**

- Command-line snippets and troubleshooting
- Backups, recovery, and disaster planning
- Migration notes and lessons learned

---

## ⚠️ Disclaimers & Scope

!!! warning "Homelab-Specific Guidance"
    - **Personal Environment:** These docs reflect my own environment, goals, and risk tolerance.
    - **Security & Scale:** Approaches described here are suited to homelab or SMB use, and may need adjustments for enterprise-scale, regulatory compliance, or higher security standards.
    - **No Credentials:** All sensitive info is redacted or generalized.
    - **Assumptions:** Some guides assume the use of specific tools, e.g. [Portainer](https://docs.bunny-lab.io/Docker%20%26%20Kubernetes/Servers/Docker/Portainer/), [AWX](https://docs.bunny-lab.io/Docker%20%26%20Kubernetes/Servers/AWX/AWX%20Operator/Ansible%20AWX%20Operator/), etc. Substitute with your preferred tools as needed.

---

## ✨ Quick Start

- Use the navigation panel to explore categories or search for keywords.
- Each section is designed to be as modular and self-contained as possible.
- Feedback and suggestions are always welcome!

---

> _“Homelabs are for learning, breaking things, and sharing the journey. Hope you find something helpful here!”_

